@@ -40,7 +40,7 @@ InitWtErgmTerm.absdiffcat <- function(nw, arglist, response, ...) {
   napositions <- is.na(nodecov)
   nodecov[napositions] <- NAsubstitute
   if(any(napositions)){u<-c(u,NA)}
-  if(!is.null(a$base)) u <- u[-(a$base)]
+  if(any(NVL(a$base,0)!=0)) u <- u[-(a$base)]
   if (length(u)==0)
     stop ("Argument to absdiffcat() has too few distinct differences", call.=FALSE)
   u2 <- u[!is.na(u)]
@@ -66,7 +66,126 @@ InitWtErgmTerm.atleast<-function(nw, arglist, response, ...) {
        coef.names=paste("atleast",a$threshold,sep="."),
        inputs=a$threshold,
        dependence=FALSE,
-       minval=0, maxval=network.dyadcount(nw,FALSE))
+       minval=0, maxval=network.dyadcount(nw,FALSE),
+       emptynwstats=if(0>=a$threshold) network.dyadcount(nw,FALSE) else 0)
+}
+
+InitWtErgmTerm.atmost<-function(nw, arglist, response, ...) {
+  a <- check.ErgmTerm(nw, arglist,
+                      varnames = c("threshold"),
+                      vartypes = c("numeric"),
+                      defaultvalues = list(0),
+                      required = c(FALSE))
+  list(name="atmost",
+       coef.names=paste("atmost",a$threshold,sep="."),
+       inputs=a$threshold,
+       dependence=FALSE,
+       minval=0, maxval=network.dyadcount(nw,FALSE),
+       emptynwstats=if(0<=a$threshold) network.dyadcount(nw,FALSE) else 0)
+}
+
+InitWtErgmTerm.b1cov<-function (nw, arglist, ...) {
+  a <- check.ErgmTerm(nw, arglist, directed=FALSE, bipartite=TRUE, 
+                      varnames = c("attrname","transform","transformname","form"),
+                      vartypes = c("character","function","character","character"),
+                      defaultvalues = list(NULL,function(x)x,"","sum"),
+                      required = c(TRUE,FALSE,FALSE,FALSE))
+  attrname<-a$attrname
+  f<-a$transform
+  f.name<-a$transformname
+  form<-match.arg(a$form,c("sum","nonzero"))
+  coef.names <- paste("b1cov",form,f.name,attrname,sep=".")
+  nb1 <- get.network.attribute(nw, "bipartite")
+  nodecov <- f(get.node.attr(nw, attrname, "b1cov", numeric=TRUE)[1:nb1])
+  # C implementation is identical
+  list(name=paste("nodeocov",form,sep="_"), coef.names=coef.names, inputs=c(nodecov), dependence=FALSE)
+}
+
+InitWtErgmTerm.b1factor<-function (nw, arglist, ...) {
+  a <- check.ErgmTerm(nw, arglist, directed=FALSE, bipartite=TRUE,
+                      varnames = c("attrname", "base", "form"),
+                      vartypes = c("character", "numeric", "character"),
+                      defaultvalues = list(NULL, 1, "sum"),
+                      required = c(TRUE, FALSE, FALSE))                                    
+  attrname<-a$attrname
+  base <- a$base
+  nb1 <- get.network.attribute(nw, "bipartite")
+  nodecov <- get.node.attr(nw, attrname, "b1factor")[1:nb1]
+  
+  if(all(is.na(nodecov)))
+	  stop("Argument to b1factor() does not exist", call.=FALSE)
+  
+  u<-sort(unique(nodecov))
+  if(any(is.na(nodecov))){u<-c(u,NA)}
+  nodecov <- match(nodecov,u,nomatch=length(u)+1)
+  ui <- seq(along=u)
+  lu <- length(ui)
+  if (lu==1){
+    stop ("Argument to b1factor() has only one value", call.=FALSE)
+  }
+  form<-match.arg(a$form,c("sum","nonzero"))
+  if(base[1]==0){
+    coef.names <- paste("b1factor", form, attrname, paste(u), sep=".")
+    inputs <- c(ui, nodecov)
+    attr(inputs, "ParamsBeforeCov") <- lu
+  }else{
+    coef.names <- paste("b1factor", form, attrname, paste(u[-base]), sep=".")
+    inputs <- c(ui[-base], nodecov)
+    attr(inputs, "ParamsBeforeCov") <- lu-length(base)
+  }
+  # C side is equivalent
+  list(name=paste("nodeofactor",form,sep="_"), coef.names=coef.names, inputs=inputs, dependence=FALSE, minval=0)
+}
+
+InitWtErgmTerm.b2cov<-function (nw, arglist, ...) {
+  a <- check.ErgmTerm(nw, arglist, directed=FALSE, bipartite=TRUE, 
+                      varnames = c("attrname","transform","transformname","form"),
+                      vartypes = c("character","function","character","character"),
+                      defaultvalues = list(NULL,function(x)x,"","sum"),
+                      required = c(TRUE,FALSE,FALSE,FALSE))
+  attrname<-a$attrname
+  f<-a$transform
+  f.name<-a$transformname
+  form<-match.arg(a$form,c("sum","nonzero"))
+  coef.names <- paste("b2cov",form,f.name,attrname,sep=".")
+  nb1 <- get.network.attribute(nw, "bipartite")
+  nodecov <- f(get.node.attr(nw, attrname, "b2cov", numeric=TRUE)[-(1:nb1)])
+  list(name=paste("b2cov",form,sep="_"), coef.names=coef.names, inputs=c(nodecov), dependence=FALSE)
+}
+
+InitWtErgmTerm.b2factor<-function (nw, arglist, ...) {
+  a <- check.ErgmTerm(nw, arglist, directed=FALSE, bipartite=TRUE,
+                      varnames = c("attrname", "base", "form"),
+                      vartypes = c("character", "numeric", "character"),
+                      defaultvalues = list(NULL, 1, "sum"),
+                      required = c(TRUE, FALSE))
+  attrname<-a$attrname
+  base <- a$base
+  nb1 <- get.network.attribute(nw, "bipartite")
+  nodecov <- get.node.attr(nw, attrname, "b2factor")[(nb1+1):network.size(nw)]
+  
+  if(all(is.na(nodecov)))
+	  stop("Argument to b2factor() does not exist", call.=FALSE)
+  
+  u<-sort(unique(nodecov))
+  if(any(is.na(nodecov))){u<-c(u,NA)}
+  nodecov <- match(nodecov,u,nomatch=length(u)+1)
+  ui <- seq(along=u)
+  lu <- length(ui)
+  if (lu==1){
+    stop ("Argument to b2factor() has only one value", call.=FALSE)
+  }
+  form<-match.arg(a$form,c("sum","nonzero"))
+  if(base[1]==0){
+    coef.names <- paste("b2factor", form, attrname, paste(u), sep=".")
+    inputs <- c(ui, nodecov)
+    attr(inputs, "ParamsBeforeCov") <- lu
+  }else{
+    coef.names <- paste("b2factor", form, attrname, paste(u[-base]), sep=".")
+    inputs <- c(ui[-base], nodecov)
+    attr(inputs, "ParamsBeforeCov") <- lu-length(base)
+  }
+  list(name=paste("b2factor",form,sep="_"), coef.names=coef.names, inputs=inputs, dependence=FALSE, minval=0) 
 }
 
 InitWtErgmTerm.edgecov <- function(nw, arglist, response, ...) {
@@ -101,6 +220,21 @@ InitWtErgmTerm.edgecov <- function(nw, arglist, response, ...) {
 }
 
 
+InitWtErgmTerm.equalto<-function(nw, arglist, response, ...) {
+  a <- check.ErgmTerm(nw, arglist,
+                      varnames = c("value", "tolerance"),
+                      vartypes = c("numeric", "numeric"),
+                      defaultvalues = list(0, 0),
+                      required = c(FALSE,FALSE))
+  list(name="ininterval",
+       coef.names=paste("equalto",a$value,"pm",a$tolerance,sep="."),
+       inputs=with(a, c(value-tolerance, value+tolerance, FALSE, FALSE)),
+       dependence=FALSE,
+       minval=0, maxval=network.dyadcount(nw,FALSE),
+       emptynwstats=if(abs(a$value)<=a$tolerance) network.dyadcount(nw,FALSE) else 0)
+}
+
+
 InitWtErgmTerm.ininterval<-function(nw, arglist, response, ...) {
   a <- check.ErgmTerm(nw, arglist,
                       varnames = c("lower","upper","open"),
@@ -110,10 +244,14 @@ InitWtErgmTerm.ininterval<-function(nw, arglist, response, ...) {
 
   a$open<-rep(a$open,length.out=2)
   list(name="ininterval",
-       coef.names=paste("ininterval",if(a$open[0]) "(" else "[", a$lower,",",a$upper, if(a$open[1]) ")" else "]",sep=""),
-       inputs=c(a$lower,a$upper,a$open),
+       coef.names=paste("ininterval",if(a$open[1]) "(" else "[", a$lower,",",a$upper, if(a$open[2]) ")" else "]",sep=""),
+       inputs=c(.deinf(a$lower),.deinf(a$upper),a$open),
        dependence=FALSE,
-       minval=0, maxval=network.dyadcount(nw,FALSE))
+       minval=0, maxval=network.dyadcount(nw,FALSE),
+       emptynwstats=if(
+       ((a$open[1] & 0>a$lower) | (!a$open[1] & 0>=a$lower)) &
+       ((a$open[2] & 0<a$upper) | (!a$open[2] & 0<=a$upper))
+       ) network.dyadcount(nw,FALSE) else 0)
 }
 
 InitWtErgmTerm.greaterthan<-function(nw, arglist, response, ...) {
@@ -122,13 +260,27 @@ InitWtErgmTerm.greaterthan<-function(nw, arglist, response, ...) {
                       vartypes = c("numeric"),
                       defaultvalues = list(0),
                       required = c(FALSE))
-  list(name="atleast",
+  list(name="greaterthan",
        coef.names=paste("greaterthan",a$threshold,sep="."),
        inputs=a$threshold,
        dependence=FALSE,
-       minval=0, maxval=network.dyadcount(nw,FALSE))
+       minval=0, maxval=network.dyadcount(nw,FALSE),
+       emptynwstats=if(0>a$threshold) network.dyadcount(nw,FALSE) else 0)
 }
 
+InitWtErgmTerm.smallerthan<-function(nw, arglist, response, ...) {
+  a <- check.ErgmTerm(nw, arglist,
+                      varnames = c("threshold"),
+                      vartypes = c("numeric"),
+                      defaultvalues = list(0),
+                      required = c(FALSE))
+  list(name="smallerthan",
+       coef.names=paste("smallerthan",a$threshold,sep="."),
+       inputs=a$threshold,
+       dependence=FALSE,
+       minval=0, maxval=network.dyadcount(nw,FALSE),
+       emptynwstats=if(0<a$threshold) network.dyadcount(nw,FALSE) else 0)
+}
 
 
 InitWtErgmTerm.sum<-function(nw, arglist, response, ...) {
@@ -238,7 +390,7 @@ InitWtErgmTerm.nodefactor<-function (nw, arglist, response, ...) {
     }
 
   u <- sort(unique(nodecov))
-  if (!is.null(a$base) && !identical(a$base,0)) {
+  if (any(NVL(a$base,0)!=0)) {
     u <- u[-a$base]
     if (length(u)==0) { # Get outta here!  (can happen if user passes attribute with one value)
       print("Warning:  nodefactor term deleted because it contributes no statistics")
@@ -291,7 +443,7 @@ InitWtErgmTerm.nodeofactor<-function (nw, arglist, response, ...) {
     }
 
   u <- sort(unique(nodecov))
-  if (!is.null(a$base) && !identical(a$base,0)) {
+  if (any(NVL(a$base,0)!=0)) {
     u <- u[-a$base]
     if (length(u)==0) { # Get outta here!  (can happen if user passes attribute with one value)
       print("Warning:  nodeofactor term deleted because it contributes no statistics")
@@ -344,7 +496,7 @@ InitWtErgmTerm.nodeifactor<-function (nw, arglist, response, ...) {
     }
 
   u <- sort(unique(nodecov))
-  if (!is.null(a$base) && !identical(a$base,0)) {
+  if (any(NVL(a$base,0)!=0)) {
     u <- u[-a$base]
     if (length(u)==0) { # Get outta here!  (can happen if user passes attribute with one value)
       print("Warning:  nodeifactor term deleted because it contributes no statistics")
@@ -443,7 +595,7 @@ InitWtErgmTerm.nodemix<-function (nw, arglist, ...) {
     nodecov <- c(b1nodecov, b2nodecov + nr)
     u <- cbind(rep(1:nr,nc), nr + rep(1:nc, each=nr))
     if(any(is.na(nodecov))){u<-rbind(u,NA)}    
-    if (!is.null(a$base) && !identical(a$base,0)) {
+    if (any(NVL(a$base,0)!=0)) {
       u <- u[-a$base,]
     }
     name <- "mix"
@@ -468,7 +620,7 @@ InitWtErgmTerm.nodemix<-function (nw, arglist, ...) {
       ucm <- ucm[upper.tri(ucm,diag=TRUE)]
       uun <- uun[upper.tri(uun,diag=TRUE)]
     }
-    if (!is.null(a$base) && !identical(a$base,0)) {
+    if (any(NVL(a$base,0)!=0)) {
       urm <- as.vector(urm)[-a$base]
       ucm <- as.vector(ucm)[-a$base]
       uun <- as.vector(uun)[-a$base]
@@ -569,7 +721,8 @@ InitWtErgmTerm.mutual<-function (nw, arglist, response, ...) {
        inputs=if(form=="threshold") a$threshold,
        dependence=TRUE,
        minval=switch(form,min=NULL,nabsdiff=NULL,threshold=0,product=NULL,geometric=0),
-       maxval=switch(form,min=NULL,nabsdiff=0,threshold=NULL,product=NULL,geometric=NULL)
+       maxval=switch(form,min=NULL,nabsdiff=0,threshold=NULL,product=NULL,geometric=NULL),
+       emptynwstats=switch(form,min=0,nabsdiff=0,threshold=if(a$threshold<=0) network.dyadcount(nw, FALSE)/2 else 0,product=0,geometric=0)
        )
 }
 
