@@ -77,7 +77,7 @@ approx.hotelling.diff.test<-function(x,y=NULL, mu0=NULL, assume.indep=FALSE, var
   novar <- diag(vcov.d)==0
   p <- p-sum(novar)
 
-  ivcov.d <-robust.inverse(vcov.d[!novar,!novar,drop=FALSE])
+  ivcov.d <-ginv(vcov.d[!novar,!novar,drop=FALSE])
   
   method <- paste("Hotelling's",
                   if(is.null(y)) "One" else "Two",
@@ -196,11 +196,18 @@ approx.hotelling.diff.test<-function(x,y=NULL, mu0=NULL, assume.indep=FALSE, var
       # biggest singular values, respectively, is greater than the
       # tolerance.
       e <- eigen(cov(x), symmetric=TRUE)
-      Q <- e$vec[,e$val>0 & sqrt(e$val/max(e$val))>tol*2,drop=FALSE]
+      Q <- e$vec[,sqrt(pmax(e$val,0)/max(e$val))>tol*2,drop=FALSE]
       xr <- x%*%Q # Columns of xr are guaranteed to be linearly independent.
 
       # Calculate the time-series variance of the mean on the PC scale.
-      arfit <- ar(xr,aic=is.null(order.max), order.max=order.max, ...)
+
+      if(is.null(order.max)){ord <- 10*log10(nrow(xr))}
+      arfit <- .catchToList(ar(xr,aic=is.null(order.max), order.max=ord, ...))
+      while(!is.null(arfit$error) & ord > 1){
+        ord <- ord - 1
+        arfit <- .catchToList(ar(xr,aic=is.null(order.max), order.max=ord, ...))
+      }
+      arfit <- arfit$value
       arvar <- arfit$var.pred
       arcoefs <- arfit$ar
       arcoefs <- if(is.null(dim(arcoefs))) sum(arcoefs) else apply(arcoefs,2:3,base::sum)
