@@ -193,6 +193,8 @@ control.ergm<-function(drop=TRUE,
                        MCMLE.effectiveSize=NULL,
                        MCMLE.last.boost=4,
                        MCMLE.Hummel.esteq=TRUE, 
+                       MCMLE.Hummel.miss.sample=100,
+                       MCMLE.Hummel.maxit=25, 
                        MCMLE.steplength.min=0.0001,
                        
                        SA.phase1_n=NULL, SA.initial_gain=NULL, 
@@ -231,6 +233,10 @@ control.ergm<-function(drop=TRUE,
                        CD.steplength=1,
                        CD.adaptive.trustregion=3,
                        CD.adaptive.epsilon=0.01,
+                       CD.Hummel.esteq=TRUE, 
+                       CD.Hummel.miss.sample=100,
+                       CD.Hummel.maxit=25, 
+                       CD.steplength.min=0.0001,
                        
                        loglik.control=control.logLik.ergm(),
 
