@@ -318,6 +318,7 @@ ergm <- function(formula, response=NULL,
                                          MHproposal.obs$arguments$constraints))
   
   # If all other criteria for MPLE=MLE are met, _and_ SAN network matches target.stats directly, we can get away with MPLE.
+  if (!is.null(target.stats) && !isTRUE(all.equal(target.stats,nw.stats))) message("Unable to match target stats. Using MCMLE estimation.")
   MCMCflag <- (estimate=="MLE" && (!MPLE.is.MLE
                                    || (!is.null(target.stats) && !isTRUE(all.equal(target.stats,nw.stats)))
   )
@@ -386,6 +387,7 @@ ergm <- function(formula, response=NULL,
     initialfit$constrained.obs <- MHproposal.obs$arguments$constraints
     initialfit$constraints <- constraints
     initialfit$target.stats <- model.initial$target.stats
+    initialfit$etamap <- model.initial$etamap
     initialfit$target.esteq <- if(!is.null(model.initial$target.stats)){
       tmp <- .ergm.esteq(initialfit$coef, model.initial, rbind(model.initial$target.stats))
       structure(c(tmp), names=colnames(tmp))
@@ -398,6 +400,7 @@ ergm <- function(formula, response=NULL,
     if(any(!model.initial$etamap$offsettheta) && eval.loglik){
       cat("Evaluating log-likelihood at the estimate. ")
       initialfit<-logLik.ergm(initialfit, add=TRUE, control=control$loglik.control, verbose=verbose)
+      cat("\n")
     }
     return(initialfit)
   }
