@@ -7,8 +7,6 @@
 #
 #  Copyright 2003-2015 Statnet Commons
 #######################################################################
-library(statnet.common)
-opttest({
 library(ergm)
 
 nsim <- 100
@@ -61,4 +59,3 @@ stopifnot(all(sweep(ys, 2, c(od(y0),id(y0)))==0))
 
 ys <- simulate(y0~sociality(base=0), constraints=~b1degrees+b2degrees, coef=rep(0,n), nsim=nsim, statsonly=TRUE)
 stopifnot(all(sweep(ys, 2, c(od(y0),id(y0)))==0))
-}, "degree constraints")
