@@ -14,7 +14,11 @@ temp.func <- function(nw,deg) {
   fit <- ergm(nw~edges+degree(deg))
   return(fit)
 }
-mynet <- network.initialize(100,directed=F)
-mynet <- simulate(mynet~edges,coef=-2)
-aaa <- temp.func(mynet,3)
+mynet <- network.initialize(50,directed=F)
+mynet <- simulate(mynet~edges,coef=-2.5)
+print(summary(mynet~edges+degree(0:20)))  
+print(temp.func(mynet,3))
+mynet <- simulate(mynet~edges,coef=-0.5)
+print(summary(mynet~edges+degree(0:20)))  
+print(temp.func(mynet,3))
 },"scoping issues (Ticket #193)")
